"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from orq_ai_sdk.types import BaseModel
import pydantic
from typing import Literal, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


RetrievalType = Literal["vector_search", "keyword_search", "hybrid_search"]
r"""The retrieval type to use for the knowledge base. If not provided, Hybrid Search will be used as a default query strategy."""


class RerankConfigTypedDict(TypedDict):
    r"""The rerank configuration for the knowledge base. In case the model is provided it will be used to enhance the search precision."""

    rerank_model: str
    r"""The rerank model to use for the knowledge base."""
    rerank_threshold: NotRequired[float]
    r"""The threshold value used to filter the rerank results, only documents with a relevance score greater than the threshold will be returned"""


class RerankConfig(BaseModel):
    r"""The rerank configuration for the knowledge base. In case the model is provided it will be used to enhance the search precision."""

    rerank_model: str
    r"""The rerank model to use for the knowledge base."""

    rerank_threshold: Optional[float] = 0.5
    r"""The threshold value used to filter the rerank results, only documents with a relevance score greater than the threshold will be returned"""


class RetrievalSettingsTypedDict(TypedDict):
    r"""The retrieval settings for the knowledge base. If not provider, Hybrid Search will be used as a default query strategy."""

    retrieval_type: NotRequired[RetrievalType]
    r"""The retrieval type to use for the knowledge base. If not provided, Hybrid Search will be used as a default query strategy."""
    top_k: NotRequired[int]
    r"""The number of results to return from the search."""
    threshold: NotRequired[float]
    r"""The threshold value used to filter the search results, only documents with a relevance score greater than the threshold will be returned"""
    rerank_config: NotRequired[RerankConfigTypedDict]
    r"""The rerank configuration for the knowledge base. In case the model is provided it will be used to enhance the search precision."""


class RetrievalSettings(BaseModel):
    r"""The retrieval settings for the knowledge base. If not provider, Hybrid Search will be used as a default query strategy."""

    retrieval_type: Optional[RetrievalType] = "hybrid_search"
    r"""The retrieval type to use for the knowledge base. If not provided, Hybrid Search will be used as a default query strategy."""

    top_k: Optional[int] = 5
    r"""The number of results to return from the search."""

    threshold: Optional[float] = 0
    r"""The threshold value used to filter the search results, only documents with a relevance score greater than the threshold will be returned"""

    rerank_config: Optional[RerankConfig] = None
    r"""The rerank configuration for the knowledge base. In case the model is provided it will be used to enhance the search precision."""


class CreateKnowledgeRequestBodyTypedDict(TypedDict):
    key: str
    embedding_model: str
    r"""The embeddings model to use for the knowledge base. This model will be used to embed the chunks when they are added to the knowledge base."""
    path: str
    r"""The path where the entity is stored in the project structure. The first element of the path always represents the project name. Any subsequent path element after the project will be created as a folder in the project if it does not exists."""
    description: NotRequired[str]
    retrieval_settings: NotRequired[RetrievalSettingsTypedDict]
    r"""The retrieval settings for the knowledge base. If not provider, Hybrid Search will be used as a default query strategy."""


class CreateKnowledgeRequestBody(BaseModel):
    key: str

    embedding_model: str
    r"""The embeddings model to use for the knowledge base. This model will be used to embed the chunks when they are added to the knowledge base."""

    path: str
    r"""The path where the entity is stored in the project structure. The first element of the path always represents the project name. Any subsequent path element after the project will be created as a folder in the project if it does not exists."""

    description: Optional[str] = None

    retrieval_settings: Optional[RetrievalSettings] = None
    r"""The retrieval settings for the knowledge base. If not provider, Hybrid Search will be used as a default query strategy."""


CreateKnowledgeRetrievalType = Literal[
    "vector_search", "keyword_search", "hybrid_search"
]
r"""The retrieval type to use for the knowledge base. If not provided, Hybrid Search will be used as a default query strategy."""


class CreateKnowledgeRerankConfigTypedDict(TypedDict):
    r"""The rerank configuration for the knowledge base. In case the model is provided it will be used to enhance the search precision."""

    rerank_model: str
    r"""The rerank model to use for the knowledge base."""
    rerank_threshold: NotRequired[float]
    r"""The threshold value used to filter the rerank results, only documents with a relevance score greater than the threshold will be returned"""


class CreateKnowledgeRerankConfig(BaseModel):
    r"""The rerank configuration for the knowledge base. In case the model is provided it will be used to enhance the search precision."""

    rerank_model: str
    r"""The rerank model to use for the knowledge base."""

    rerank_threshold: Optional[float] = 0.5
    r"""The threshold value used to filter the rerank results, only documents with a relevance score greater than the threshold will be returned"""


class CreateKnowledgeRetrievalSettingsTypedDict(TypedDict):
    r"""The retrieval settings for the knowledge base. If not provider, Hybrid Search will be used as a default query strategy."""

    retrieval_type: NotRequired[CreateKnowledgeRetrievalType]
    r"""The retrieval type to use for the knowledge base. If not provided, Hybrid Search will be used as a default query strategy."""
    top_k: NotRequired[int]
    r"""The number of results to return from the search."""
    threshold: NotRequired[float]
    r"""The threshold value used to filter the search results, only documents with a relevance score greater than the threshold will be returned"""
    rerank_config: NotRequired[CreateKnowledgeRerankConfigTypedDict]
    r"""The rerank configuration for the knowledge base. In case the model is provided it will be used to enhance the search precision."""


class CreateKnowledgeRetrievalSettings(BaseModel):
    r"""The retrieval settings for the knowledge base. If not provider, Hybrid Search will be used as a default query strategy."""

    retrieval_type: Optional[CreateKnowledgeRetrievalType] = "hybrid_search"
    r"""The retrieval type to use for the knowledge base. If not provided, Hybrid Search will be used as a default query strategy."""

    top_k: Optional[int] = 5
    r"""The number of results to return from the search."""

    threshold: Optional[float] = 0
    r"""The threshold value used to filter the search results, only documents with a relevance score greater than the threshold will be returned"""

    rerank_config: Optional[CreateKnowledgeRerankConfig] = None
    r"""The rerank configuration for the knowledge base. In case the model is provided it will be used to enhance the search precision."""


class CreateKnowledgeResponseBodyTypedDict(TypedDict):
    r"""Knowledge Base object"""

    id: str
    r"""The unique identifier of the knowledge base."""
    created_by_id: str
    r"""The id of the resource"""
    created: str
    r"""The creation date of the knowledge base."""
    key: str
    r"""The unique key of the knowledge base."""
    model: str
    r"""The embeddings model used for the knowledge base."""
    update_by_id: str
    r"""The id of the resource"""
    updated: str
    r"""The last update date of the knowledge base."""
    description: NotRequired[str]
    r"""The description of the knowledge base."""
    path: NotRequired[str]
    r"""The path where the entity is stored in the project structure. The first element of the path always represents the project name. Any subsequent path element after the project will be created as a folder in the project if it does not exists."""
    retrieval_settings: NotRequired[CreateKnowledgeRetrievalSettingsTypedDict]
    r"""The retrieval settings for the knowledge base. If not provider, Hybrid Search will be used as a default query strategy."""


class CreateKnowledgeResponseBody(BaseModel):
    r"""Knowledge Base object"""

    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""The unique identifier of the knowledge base."""

    created_by_id: str
    r"""The id of the resource"""

    created: str
    r"""The creation date of the knowledge base."""

    key: str
    r"""The unique key of the knowledge base."""

    model: str
    r"""The embeddings model used for the knowledge base."""

    update_by_id: str
    r"""The id of the resource"""

    updated: str
    r"""The last update date of the knowledge base."""

    description: Optional[str] = None
    r"""The description of the knowledge base."""

    path: Optional[str] = None
    r"""The path where the entity is stored in the project structure. The first element of the path always represents the project name. Any subsequent path element after the project will be created as a folder in the project if it does not exists."""

    retrieval_settings: Optional[CreateKnowledgeRetrievalSettings] = None
    r"""The retrieval settings for the knowledge base. If not provider, Hybrid Search will be used as a default query strategy."""
